.. _tutor_benchmark_tut1_bench:

Tutorial 1: BenchMark
=====================

Command line
^^^^^^^^^^^^

It is controlled via command start-benchmark with following options.

Optional: 

* --details: print test details

Tests
^^^^^

* factorial - calculate factorials up to 1e4
* fibonacci - calculate Fibonnaci numbers up to 1e4
* floating point - perform 1e9 operations in floating point
* event throughput - fire 1e7 events with 1kB